#ifndef NT2_INCLUDE_FUNCTIONS_ERFCINV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ERFCINV_HPP_INCLUDED

#include <nt2/euler/include/functions/erfcinv.hpp>

#endif
